@@ -608,6 +608,23 @@ class Variogram(object):
 
     @property
     def bins(self):
+        """Distance lag bins
+
+        Independent variable of the the experimental variogram sample.
+        The bins are the upper edges of all calculated distance lag
+        classes. If you need bin centers, use
+        :func:`get_empirical <skgstat.Variogram.get_empirical>`.
+
+        Returns
+        -------
+        bins : numpy.ndarray
+            1D array of the distance lag classes.
+
+        See Also
+        --------
+        Variogram.get_empirical
+
+        """
         # if bins are not calculated, do it
         if self._bins is None:
             self._bins, n = self.bin_func(self.distance, self._n_lags, self.maxlag)
@@ -621,7 +638,7 @@ class Variogram(object):
     @bins.setter
     def bins(self, bins):
         # set the new bins
-        self._bins = bins
+        self._bins = np.asarray(bins)
 
         # clean the groups as they are not valid anymore
         self._groups = None
@@ -662,7 +679,7 @@ class Variogram(object):
         # else
         else:
             raise ValueError('n_lags has to be a positive integer')
-        
+
         # if there are no errors, store the passed value
         self._n_lags_passed_value = n
 
@@ -702,8 +719,10 @@ class Variogram(object):
                 self._estimator = estimators.entropy
             else:
                 raise ValueError(
-                    ('Variogram estimator %s is not understood, please ' +
-                    'provide the function.') % estimator_name
+                    (
+                        'Variogram estimator %s is not understood, please '
+                        'provide the function.'
+                    ) % estimator_name
                 )
         elif callable(estimator_name):
             self._estimator = estimator_name
@@ -746,7 +765,11 @@ class Variogram(object):
                 self._model = self._build_harmonized_model()
             else:
                 raise ValueError(
-                    'The theoretical Variogram function %s is not understood, please provide the function' % model_name)
+                    (
+                        'The theoretical Variogram function %s is not'
+                        ' understood, please provide the function'
+                    ) % model_name
+                )
         else:
             self._model = model_name
 
@@ -811,7 +834,7 @@ class Variogram(object):
             return self._dist_func_name(x)
         else:
             return pdist(X=x, metric=self._dist_func_name)
-    
+
     @dist_function.setter
     def dist_function(self, func):
         self.set_dist_function(func=func)
@@ -1459,10 +1482,10 @@ class Variogram(object):
 
         .. versionchanged:: 0.3.6
             replaced the for-loops with :func:`fromiter <numpy.fromiter>`
-        
+
         .. versionchanged:: 0.3.7
-            makes use of `kwargs <skgstat.Variogram._kwargs>` for 
-            specific estimators now 
+            makes use of `kwargs <skgstat.Variogram._kwargs>` for
+            specific estimators now
 
         Returns
         -------
@@ -1478,7 +1501,7 @@ class Variogram(object):
             # we need to use N -1 as we use the last inclusive
             if isinstance(N, int):
                 N -= 1
-            
+
             bins = np.histogram_bin_edges(self.distance, bins=N)
 
             # define the mapper to the estimator function
@@ -1500,6 +1523,49 @@ class Variogram(object):
         # return the mapped result
         return np.fromiter(map(mapper, self.lag_classes()), dtype=float)
 
+    def get_empirical(self, bin_center=False):
+        """Empirical variogram
+
+        Returns a tuple of dependent and independent sample values, this
+        :class:`Variogram <skgstat.Variogram>` is estimated for.
+        This is a tuple of the current :func:`bins <skgstat.Variogram.bins>`
+        and :func:`experimental <skgstat.Variogram.experimental>`
+        semi-variance values. By default the upper bin edges are used.
+        This can be set to bin center by the `bin_center` argument.
+
+        Parameters
+        ----------
+        bin_center : bool
+            If set to `True`, the center for each distance lag bin is
+            used over the upper limit (default).
+
+        Returns
+        -------
+        bins : numpy.ndarray
+            1D array of :func:`n_lags <skgstat.Variogram.n_lags>`
+            distance lag bins.
+        experimental : numpy.ndarray
+            1D array of :func:`n_lags <skgstat.Variogram.n_lags>`
+            experimental semi-variance values.
+
+        See Also
+        --------
+        Variogram.bins
+        Variogram.experimental
+
+        """
+        # get the bins and experimental values
+        bins = self.bins
+        experimental = self.experimental
+
+        # align bin centers
+        if bin_center:
+            # get the bin centers
+            bins = np.subtract(bins, np.diff([0] + bins.tolist()) / 2)
+
+        # return
+        return bins, experimental
+
     def __get_fit_bounds(self, x, y):
         """
         Return the bounds for parameter space in fitting a variogram model.
