@@ -1,5 +1,8 @@
 import numpy as np
 from sklearn.cluster import KMeans, AgglomerativeClustering
+from scipy.optimize import minimize, OptimizeWarning
+
+from skgstat.util import shannon_entropy
 
 
 def even_width_lags(distances, n, maxlag):
@@ -104,7 +107,7 @@ def auto_derived_lags(distances, method_name, maxlag):
     numpy.histogram_bin_edges
 
     """
-    # maxlags largher than maximum separating distance will be ignored
+    # maxlags larger than maximum separating distance will be ignored
     if maxlag is None or maxlag > np.nanmax(distances):
         maxlag = np.nanmax(distances)
 
@@ -150,7 +153,7 @@ def kmeans(distances, n, maxlag, binning_random_state=42, **kwargs):
     `Variogram <skgstat.Variogram>` as `binning_random_state`. 
 
     """
-    # maxlags largher than maximum separating distance will be ignored
+    # maxlags larger than maximum separating distance will be ignored
     if maxlag is None or maxlag > np.nanmax(distances):
         maxlag = np.nanmax(distances)
 
@@ -197,7 +200,7 @@ def ward(distances, n, maxlag, **kwargs):
         The **upper** bin edges of the lag classes
 
     """
-    # maxlags largher than maximum separating distance will be ignored
+    # maxlags larger than maximum separating distance will be ignored
     if maxlag is None or maxlag > np.nanmax(distances):
         maxlag = np.nanmax(distances)
 
@@ -221,3 +224,72 @@ def ward(distances, n, maxlag, **kwargs):
     edges = np.fromiter(((low + up) / 2 for low, up in bounds), dtype=float)
 
     return edges, None
+
+
+def stable_entropy_lags(distances, n, maxlag, **kwargs):
+    """Stable lags
+    .. versionadded: 0.4.0
+
+    Optimizes the lag class edges for `n` lag classes.
+    The algorithm minimizes the difference between Shannon
+    Entropy for each lag class. Consequently, the final
+    lag classes should be of comparable uncertainty.
+
+    Parameters
+    ----------
+    distances : numpy.array
+        Flat numpy array representing the upper triangle of
+        the distance matrix.
+    n : integer
+        Amount of lag classes to find
+    maxlag : integer, float
+        Limit the last lag class to this separating distance.
+
+    Keyword Arguments
+    -----------------
+    binning_maxiter : int
+        Maximum iterations before the optimization is stopped,
+        if the lag edges do not converge.
+    binning_entropy_bins : int, str
+        Binning method for calculating the shannon entropy
+        on each iteration.
+    Returns
+    -------
+    bin_edges : numpy.ndarray
+        The **upper** bin edges of the lag classes
+
+    """
+    # maxlags larger than maximum separating distance will be ignored
+    if maxlag is None or maxlag > np.nanmax(distances):
+        maxlag = np.nanmax(distances)
+
+    # filter for distances < maxlag
+    d = distances[np.where(distances <= maxlag)]
+
+    # create a global binning and initial guess
+    bins = np.histogram_bin_edges(d, bins=kwargs.get('binning_entropy_bins', 'sqrt'))
+    initial_guess = np.linspace(0, np.nanmax(d), n + 1)[1:]
+
+    # define the loss function
+    def loss(edges):
+        # get the shannon entropy for the current binning
+        h = np.ones(len(edges) - 1) * 9999
+        for i, bnd in enumerate(zip(edges, edges[1:])):
+            l, u = bnd
+            x = d[np.where((d >= l) & (d < u))[0]]
+            if len(x) == 0:
+                continue
+            else:
+                h[i] = shannon_entropy(x, bins)
+
+        # return the absolute differences between the bins
+        return np.sum(np.abs(np.diff(h)))
+
+    # minimize the loss function
+    opt = dict(maxiter=kwargs.get('binning_maxiter', 5000)) 
+    res = minimize(loss, initial_guess, method='Nelder-Mead', options=opt)
+
+    if res.success:
+        return res.x, None
+    else:  # pragma: no cover
+        raise OptimizeWarning("Failed to find optimal lag classes.")
